import { h } from '../docs.core.js';

class ApiName {
    static get is() { return "ad-api-name"; }
    static get style() { return "ad-api-name:after{color:var(--anj-secondary-dark);content:\":\";margin-right:.5rem}"; }
}

class ArgDef {
    render() {
        return [
            h("ad-api-name", null, this.arg.name),
            h("ad-type-def", null, this.arg.type)
        ];
    }
    static get is() { return "ad-arg-def"; }
    static get properties() { return {
        "arg": {
            "type": "Any",
            "attr": "arg"
        }
    }; }
    static get style() { return "ad-arg-def:after{color:var(--anj-secondary-dark);content:\",\";margin-right:.5rem}ad-arg-def:last-child:after{content:none;margin-right:0}"; }
}

class Decorator {
    static get is() { return "ad-decorator"; }
    static get style() { return "ad-decorator{color:var(--anj-secondary-dark)}.api.ng ad-method-def ad-decorator,.api.ng ad-prop-def ad-decorator{display:none}"; }
}

class EventDef {
    render() {
        return [
            h("h4", null,
                h("ad-decorator", null, "@Event"),
                "\u00A0",
                h("ad-api-name", null, this.event.event)),
            h("p", null, this.event.docs)
        ];
    }
    static get is() { return "ad-event-def"; }
    static get properties() { return {
        "event": {
            "type": "Any",
            "attr": "event"
        }
    }; }
    static get style() { return "ad-event-def,ad-input-def,ad-method-def,ad-output-def,ad-prop-def{display:block;margin-bottom:1.5rem}ad-event-def h4,ad-input-def h4,ad-method-def h4,ad-output-def h4,ad-prop-def h4{color:var(--anj-dark);font-size:1rem;font-weight:400;margin:0 0 .5rem;padding:0}"; }
}

class InputDef {
    render() {
        return [
            h("h4", null,
                h("ad-decorator", null, "@Input\u00A0"),
                h("ad-api-name", null, this.input.name),
                h("ad-type-def", null, this.input.type)),
            h("p", null, this.input.docs)
        ];
    }
    static get is() { return "ad-input-def"; }
    static get properties() { return {
        "input": {
            "type": "Any",
            "attr": "input"
        }
    }; }
    static get style() { return "ad-event-def,ad-input-def,ad-method-def,ad-output-def,ad-prop-def{display:block;margin-bottom:1.5rem}ad-event-def h4,ad-input-def h4,ad-method-def h4,ad-output-def h4,ad-prop-def h4{color:var(--anj-dark);font-size:1rem;font-weight:400;margin:0 0 .5rem;padding:0}"; }
}

class MethodDef {
    nameless(name) {
        return `(${name.split('(')[1]}`;
    }
    render() {
        return [
            h("h4", null,
                h("ad-decorator", null, "@Method\u00A0"),
                h("ad-api-name", null, this.method.name),
                h("ad-type-def", null, this.nameless(this.method.signature))),
            h("p", null, this.method.docs)
        ];
    }
    static get is() { return "ad-method-def"; }
    static get properties() { return {
        "method": {
            "type": "Any",
            "attr": "method"
        }
    }; }
    static get style() { return "ad-event-def,ad-input-def,ad-method-def,ad-output-def,ad-prop-def{display:block;margin-bottom:1.5rem}ad-event-def h4,ad-input-def h4,ad-method-def h4,ad-output-def h4,ad-prop-def h4{color:var(--anj-dark);font-size:1rem;font-weight:400;margin:0 0 .5rem;padding:0}"; }
}

class OutputDef {
    render() {
        return [
            h("h4", null,
                h("ad-decorator", null, "@Output\u00A0"),
                h("ad-api-name", null, this.output.name),
                h("ad-type-def", null, this.output.type)),
            h("p", null, this.output.docs)
        ];
    }
    static get is() { return "ad-output-def"; }
    static get properties() { return {
        "output": {
            "type": "Any",
            "attr": "output"
        }
    }; }
    static get style() { return "ad-event-def,ad-input-def,ad-method-def,ad-output-def,ad-prop-def{display:block;margin-bottom:1.5rem}ad-event-def h4,ad-input-def h4,ad-method-def h4,ad-output-def h4,ad-prop-def h4{color:var(--anj-dark);font-size:1rem;font-weight:400;margin:0 0 .5rem;padding:0}"; }
}

class PropDef {
    render() {
        return [
            h("h4", null,
                h("ad-decorator", null, "@Prop\u00A0"),
                h("ad-api-name", null, this.prop.name),
                h("ad-type-def", null, this.prop.type)),
            h("p", null, this.prop.docs)
        ];
    }
    static get is() { return "ad-prop-def"; }
    static get properties() { return {
        "prop": {
            "type": "Any",
            "attr": "prop"
        }
    }; }
    static get style() { return "ad-event-def,ad-input-def,ad-method-def,ad-output-def,ad-prop-def{display:block;margin-bottom:1.5rem}ad-event-def h4,ad-input-def h4,ad-method-def h4,ad-output-def h4,ad-prop-def h4{color:var(--anj-dark);font-size:1rem;font-weight:400;margin:0 0 .5rem;padding:0}"; }
}

class RealTime {
    static get is() { return "ad-real-time"; }
    static get style() { return "ad-real-time{border:1px dashed var(--anj-border);border-radius:.25rem;display:block;margin-top:1.5rem;padding:1rem}"; }
}

class TypeDef {
    static get is() { return "ad-type-def"; }
    static get style() { return "ad-type-def{color:var(--anj-neutral);font-size:.75rem}"; }
}

export { ApiName as AdApiName, ArgDef as AdArgDef, Decorator as AdDecorator, EventDef as AdEventDef, InputDef as AdInputDef, MethodDef as AdMethodDef, OutputDef as AdOutputDef, PropDef as AdPropDef, RealTime as AdRealTime, TypeDef as AdTypeDef };
